@@ -1,6 +1,6 @@
 /* edit.c -- bitmap file manipulation and editing */
 /*
-Copyright 2002 John Coffman.
+Copyright 2002-2004 John Coffman.
 All rights reserved.
 
 Licensed under the terms contained in the file 'COPYING' in the 
@@ -8,6 +8,7 @@ source directory.
 
 */
 
+#define _GNU_SOURCE
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/statfs.h>
@@ -62,9 +63,9 @@ static BITMAPLILOHEADER lh0 = {
 
 
 #if USE_BSECT_PW_INPUT
-#define getline pw_input
+#define getLine pw_input
 #else
-static char *getline(void)
+static char *getLine(void)
 {
     char *pass;
     char buf[MAX_TOKEN+1];
@@ -104,7 +105,7 @@ int get_std_headers(int fd,
 	n = bmh->numBitPlanes = bmh2.numBitPlanes;
 	n *= bmh->numBitsPerPlane = bmh2.numBitsPerPlane;
 	bmh->numColorsUsed = bmh->numImportantColors = 1 << n;
-	bmh->sizeImageData = *(long*)(fh->size) - *(long*)(fh->offsetToBits);
+	bmh->sizeImageData = *(int*)(fh->size) - *(int*)(fh->offsetToBits);
 	bmh->size = sizeof(*bmh);    /* new size!! */
 	n = sizeof(RGB2);
     }
@@ -124,7 +125,7 @@ int get_std_headers(int fd,
 	if (read(fd, &palette[i], n) != n)  return -1;
 	if (n==sizeof(RGB2)) palette[i].null = 0;
     }
-    if (*(long*)(fh->offsetToBits) == sizeof(BITMAPFILEHEADER) +
+    if (*(int*)(fh->offsetToBits) == sizeof(BITMAPFILEHEADER) +
     		sizeof(BITMAPHEADER) + sizeof(BITMAPLILOHEADER) +
     		npal*sizeof(RGB) )  /* test will fail for OS/2 bitmaps */ {
       /* get probable BITMAPLILOHEADER */
@@ -132,7 +133,7 @@ int get_std_headers(int fd,
 	if (size != sizeof(BITMAPLILOHEADER))   return 4;
 	if (read(fd, (void*)lh+sizeof(size), sizeof(*lh)-sizeof(size)) !=
 		sizeof(*lh)-sizeof(size))  return -1;
-	*(long*)(lh->size) = size;
+	*(int*)(lh->size) = size;
 	if (strncmp(lh->magic, "LILO", 4) != 0)   return 5;
     } else { /* there is no BITMAPLILOHEADER present */
 #ifdef STANDALONE
@@ -170,10 +171,10 @@ int put_std_bmpfile(int fd, int ifd,
 	else if (n<0)  printf("Error reading input\n");
     } while (n>0);
     bmh->sizeImageData = total;
-    *(long*)(fh->offsetToBits) = n = sizeof(BITMAPFILEHEADER) +
+    *(int*)(fh->offsetToBits) = n = sizeof(BITMAPFILEHEADER) +
     		sizeof(BITMAPHEADER) + sizeof(BITMAPLILOHEADER) +
     		npalette*sizeof(RGB);
-    *(long*)(fh->size) = total + n;
+    *(int*)(fh->size) = total + n;
     lseek(fd, 0, SEEK_SET);
     write(fd, fh, sizeof(*fh));
     write(fd, bmh, sizeof(*bmh));
@@ -192,7 +193,7 @@ static	union {
 	} tm;
 static	MENUTABLE *menu = &tm.mt;
 static	BITMAPLILOHEADER *lh = (void*)tm.buffer + 
-    			((int)&tm.mt.row - (int)&tm.bmlh.row);
+    			((long)&tm.mt.row - (long)&tm.bmlh.row);
 
 /* a convenience definition */
 #define mn tm.mt
@@ -207,7 +208,7 @@ static int yesno(char *query, int def)
 
     while (ans>1) {    
 	printf("%s (yes or no) [%c]:  ", query, def?'Y':'N');
-	yn = getline();
+	yn = getLine();
 	if (!*yn) ans = def;
 	else if (toupper(*yn) == 'Y') ans = 1;
 	else if (toupper(*yn) == 'N') ans = 0;
@@ -360,7 +361,7 @@ static char *op[] = { "", ",transparent", ",none" };
 	printf("%s text %s color (0..%d%s) [%s]: ", what, co[i], npal-1, op[i],
 		i==1 && tr ? "transparent" :
 		i==2 && no ? "none" : n);
-	line = getline();
+	line = getLine();
 	if (!*line) c = dcol[i];
 	else if (toupper(*line)=='T' && i==1) c = color[0];
 	else if (toupper(*line)=='N' && i==2) c = color[0];
@@ -387,7 +388,7 @@ static void number(char *what, short *num, int min, int max)
     int val;
     
     printf("%s (%d..%d) [%hd]:  ", what, min, max, *num);
-    line = getline();
+    line = getLine();
     if (!*line) val = *num;
     else {
 	val = strtol(line, &end, 0);
@@ -415,7 +416,7 @@ static void getXY(char *what, short *locp, int scale, int abs)
     printf("%s (%d..%d) or (%dp..%dp) [%d%s or %dp]: ", what,
     			min, max, minp, maxp, loc, plus, (int)*locp);
     
-    line = getline();
+    line = getLine();
     if (!*line) val = *locp;
     else {
 	val = strtol(line, &end, 0);
@@ -486,7 +487,7 @@ static void edit_timer(void)
 	
 	printf(", B)ack:  ");
 	
-	cmd = getline();
+	cmd = getLine();
 	
 	if (timer) switch(toupper(*cmd)) {
 	    case 'C':
@@ -535,7 +536,7 @@ static void edit_layout(void)
     	
 	printf("\nLayout options:  D)imensions, P)osition, B)ack:  ");
 
-	cmd = getline();
+	cmd = getLine();
 	switch(toupper(*cmd)) {
 	    case 'D':
 		number("\nNumber of columns", &mn.ncol, 1, 80/MAX_IMAGE_NAME);
@@ -574,7 +575,7 @@ static void edit_colors(void)
 	if (timer) printf("T)imer, ");
 	printf("B)ack:  ");
 
-	cmd = getline();
+	cmd = getLine();
 	switch(toupper(*cmd)) {
 	    case 'N':
 		get3colors("Normal text", &mn.fg);
@@ -615,7 +616,7 @@ static void edit_bitmap(char *bitmap_file)
 	show_timer();
 	
 	printf("\nCommands are:  L)ayout, C)olors, T)imer, Q)uit, W)rite:  ");
-	cmd = getline();
+	cmd = getLine();
 	switch(toupper(*cmd)) {
 	    case 'C':
 		edit_colors();
