@@ -93,9 +93,11 @@ source directory.
 
 /* the known major device numbers */
 #define MAJMIN_RAM	0x101 /* RAM disk */
+#ifdef LCF_MDPRAID
 #define MAJOR_MDP_SORT  1 /* Convert MAJOR_MDP to this for sorting */
+#endif
 #define MAJOR_EMD_SORT  2 /* Convert MAJOR_EMD to this for sorting */
-#define MAJOR_HPT370_SORT  2 /* Convert MAJOR_HPT320 to this for sorting */
+#define MAJOR_HPT370_SORT  2 /* Convert MAJOR_HPT370 to this for sorting */
 #define MAJOR_FD	2 /* floppy disks */
 #define MAJOR_HD	3 /* IDE-type hard disks */
 #define MAJOR_LOOP	7 /* Loopback devices 0-15 */
@@ -147,7 +149,7 @@ source directory.
 #define MAJOR_EMD	153 /* Enhanced multi-disk RAID sets */
 #define MAJOR_SATA	160 /* Carmel SATA Disk on first 8-port controller */
 #define MAJOR_SATA2	161 /* Carmel SATA Disk on 2nd 8-port controller */
-#define MAJOR_DM	253 /* linux/drivers/md/dm.c RAID set [experimental?] */
+/* don't use the following */
 #define MAJOR_MDP	254 /* Enhanced multi-disk RAID sets [experimental?] */
 
 #define MAX_TOKEN	1023 /* max device Token length */
